aboutsummaryrefslogtreecommitdiffhomepage
path: root/tensorflow/core/util/stat_summarizer.h
diff options
context:
space:
mode:
authorGravatar Andrew Harp <andrewharp@google.com>2016-11-11 16:43:51 -0800
committerGravatar TensorFlower Gardener <gardener@tensorflow.org>2016-11-11 17:02:51 -0800
commit1743ad893859ea342c3c6b04a5292b763ae4aead (patch)
treeb02f61f10035aa0004e338084fe2841dcbbc9b18 /tensorflow/core/util/stat_summarizer.h
parentf27dea2f016baf09040bf5aec705511486a3f205 (diff)
Add python wrapper for StatSummarizer.
Change: 138933733
Diffstat (limited to 'tensorflow/core/util/stat_summarizer.h')
-rw-r--r--tensorflow/core/util/stat_summarizer.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/tensorflow/core/util/stat_summarizer.h b/tensorflow/core/util/stat_summarizer.h
index 2dd3dbd5cd..7fc43d449b 100644
--- a/tensorflow/core/util/stat_summarizer.h
+++ b/tensorflow/core/util/stat_summarizer.h
@@ -111,8 +111,11 @@ class StatSummarizer {
// Adds another run's StepStats output to the aggregate counts.
void ProcessStepStats(const StepStats& step_stats);
- // Prints all the accumulated runtime stats in a tab-separated format which
- // can be pasted into a spreadsheet for further analysis.
+ // Returns a string detailing the accumulated runtime stats in a tab-separated
+ // format which can be pasted into a spreadsheet for further analysis.
+ std::string GetOutputString() const;
+
+ // Prints the string returned by GetOutputString().
void PrintStepStats() const;
// Prints the output tensor sizes and types for each node.